@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,10 +18,11 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import log, pi, exp, isinf
+from math import sqrt, log, pi, exp, isinf
 from fluids.constants import R
 from fluids.numerics import secant, newton, ridder, lambertw
 
@@ -34,10 +35,7 @@ __all__ = ['Panhandle_A', 'Panhandle_B', 'Weymouth', 'Spitzglass_high',
            'is_critical_flow', 'stagnation_energy', 'P_stagnation',
            'T_stagnation', 'T_stagnation_ideal']
 
-__numba_additional_funcs__ = ['isothermal_gas_err_P1', 'isothermal_gas_err_P2',
-                              'isothermal_gas_err_P2_basis', 'isothermal_gas_err_D']
-
-def isothermal_work_compression(P1, P2, T, Z=1):
+def isothermal_work_compression(P1, P2, T, Z=1.0):
     r'''Calculates the work of compression or expansion of a gas going through
     an isothermal process.
 
@@ -104,7 +102,7 @@ def isothermal_work_compression(P1, P2, T, Z=1):
     return Z*R*T*log(P2/P1)
 
 
-def isentropic_work_compression(T1, k, Z=1, P1=None, P2=None, W=None, eta=None):
+def isentropic_work_compression(T1, k, Z=1.0, P1=None, P2=None, W=None, eta=None):
     r'''Calculation function for dealing with compressing or expanding a gas
     going through an isentropic, adiabatic process assuming constant Cp and Cv. 
     The polytropic model is the same equation; just provide `n` instead of `k` 
@@ -208,7 +206,7 @@ def isentropic_work_compression(T1, k, Z=1, P1=None, P2=None, W=None, eta=None):
     elif eta is None and P1 is not None and P2 is not None and W is not None:
         return R*T1*Z*k*((P2/P1)**((k - 1.0)/k) - 1.0)/(W*(k - 1.0))
     else:
-        raise Exception('Three of W, P1, P2, and eta must be specified.')
+        raise ValueError('Three of W, P1, P2, and eta must be specified.')
 
 
 def isentropic_T_rise_compression(T1, P1, P2, k, eta=1):
@@ -319,7 +317,7 @@ def isentropic_efficiency(P1, P2, k, eta_s=None, eta_p=None):
         return (k - 1.0)*log(P2/P1)/(k*log(
             (eta_s + (P2/P1)**((k - 1.0)/k) - 1.0)/eta_s))
     else:
-        raise Exception('Either eta_s or eta_p is required')
+        raise ValueError('Either eta_s or eta_p is required')
 
 
 def polytropic_exponent(k, n=None, eta_p=None):
@@ -368,7 +366,7 @@ def polytropic_exponent(k, n=None, eta_p=None):
     elif eta_p is None and n is not None:
         return n*(k - 1.0)/(k*(n - 1.0))
     else:
-        raise Exception('Either n or eta_p is required')
+        raise ValueError('Either n or eta_p is required')
 
 
 def T_critical_flow(T, k):
@@ -502,14 +500,14 @@ def P_isothermal_critical_flow(P, fd, D, L):
 
 
 def P_upstream_isothermal_critical_flow(P, fd, D, L):
-    '''Not part of the public API. Reverses `P_isothermal_critical_flow`.
+    """Not part of the public API. Reverses `P_isothermal_critical_flow`.
 
     Examples
     --------
     >>> P_upstream_isothermal_critical_flow(P=389699.7317645518, fd=0.00185,
     ... L=1000., D=0.5)
     1000000.0000000001
-    '''
+    """
     lambertw_term = float(lambertw(-exp(-(fd*L+D)/D), -1).real)
     return exp(-0.5*(D*lambertw_term+fd*L+D)/D)*P
 
@@ -841,7 +839,7 @@ def isothermal_gas(rho, fd, P1=None, P2=None, L=None, D=None, m=None):
         if P2 > P1:
             raise ValueError('Specified outlet pressure is larger than the '
                              'inlet pressure; fluid will flow backwards.')
-        return (0.0625*pi*pi*D**4*rho/(P1*(fd*L/D + 2.0*log(P1/P2)))*(P1*P1 - P2*P2))**0.5
+        return sqrt(0.0625*pi*pi*D**4*rho/(P1*(fd*L/D + 2.0*log(P1/P2)))*(P1*P1 - P2*P2))
     elif L is None and P1 is not None and P2 is not None and D is not None and m is not None:
         return D*(pi*pi*D**4*rho*(P1*P1 - P2*P2) - 32.0*P1*m*m*log(P1/P2))/(16.0*P1*fd*m*m)
     elif P1 is None and L is not None and P2 is not None and D is not None and m is not None:
@@ -908,7 +906,7 @@ must be provided.')
 
 
 def Panhandle_A(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-                Ps=101325., Zavg=1, E=0.92):
+                Ps=101325., Zavg=1.0, E=0.92):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Panhandle A formula. Can calculate any of the following,
     given all other inputs:
@@ -943,7 +941,7 @@ def Panhandle_A(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1018,19 +1016,19 @@ def Panhandle_A(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Q*(Ts/Ps)**(-c1)*(SG**(-c2)*(P1**2 - P2**2)/(L*Tavg*Zavg))**(-c3)/(E*c5))**(1./c4)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P2**2)**0.5
+        return sqrt(L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P1**2)**0.5
+        return sqrt(-L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return SG**(-c2)*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(-1./c3)*(P1**2 - P2**2)/(Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
 
 def Panhandle_B(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-                Ps=101325., Zavg=1, E=0.92):
+                Ps=101325., Zavg=1.0, E=0.92):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Panhandle B formula. Can calculate any of the following,
     given all other inputs:
@@ -1065,7 +1063,7 @@ def Panhandle_B(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1137,19 +1135,19 @@ def Panhandle_B(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Q*(Ts/Ps)**(-c1)*(SG**(-c2)*(P1**2 - P2**2)/(L*Tavg*Zavg))**(-c3)/(E*c5))**(1./c4)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P2**2)**0.5
+        return sqrt(L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P1**2)**0.5
+        return sqrt(-L*SG**c2*Tavg*Zavg*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(1./c3) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return SG**(-c2)*(D**(-c4)*Q*(Ts/Ps)**(-c1)/(E*c5))**(-1./c3)*(P1**2 - P2**2)/(Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
 
 def Weymouth(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-             Ps=101325., Zavg=1, E=0.92):
+             Ps=101325., Zavg=1.0, E=0.92):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Weymouth formula. Can calculate any of the following,
     given all other inputs:
@@ -1184,7 +1182,7 @@ def Weymouth(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1253,19 +1251,23 @@ def Weymouth(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Ps*Q*((P1**2 - P2**2)/(L*SG*Tavg*Zavg))**(-c3)/(E*Ts*c5))**(1./c4)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*SG*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P2**2)**0.5
+        return sqrt(L*SG*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*SG*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P1**2)**0.5
+        return sqrt(-L*SG*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return (D**(-c4)*Ps*Q/(E*Ts*c5))**(-1./c3)*(P1**2 - P2**2)/(SG*Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
 
+def _to_solve_Spitzglass_high(D, Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E):
+     return Q - Spitzglass_high(SG=SG, Tavg=Tavg, L=L, D=D,
+                                  P1=P1, P2=P2, Ts=Ts, Ps=Ps,Zavg=Zavg, E=E)
+
 def Spitzglass_high(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-                Ps=101325., Zavg=1, E=1.):
+                Ps=101325., Zavg=1.0, E=1.):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Spitzglass (high pressure drop) formula. Can calculate
     any of the following, given all other inputs:
@@ -1301,7 +1303,7 @@ def Spitzglass_high(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1343,34 +1345,33 @@ def Spitzglass_high(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7
     c4 = 0.09144
     c5 = 125.1060
     if Q is None and L is not None and D is not None and P1 is not None and P2 is not None:
-        return (c5*E*Ts/Ps*D**2.5*((P1**2-P2**2)
-                /(L*SG*Zavg*Tavg*(1 + c4/D + c3*D)))**0.5)
+        return (c5*E*Ts/Ps*D**2.5*sqrt((P1**2-P2**2)
+                        /(L*SG*Zavg*Tavg*(1 + c4/D + c3*D))))
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
-        to_solve = lambda D : Q - Spitzglass_high(SG=SG, Tavg=Tavg, L=L, D=D,
-                                                  P1=P1, P2=P2, Ts=Ts, Ps=Ps,
-                                                  Zavg=Zavg, E=E)
-        return secant(to_solve, 0.5)
+        return secant(_to_solve_Spitzglass_high, 0.5, args=(Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E))
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return ((D**6*E**2*P2**2*Ts**2*c5**2
-                 + D**2*L*Ps**2*Q**2*SG*Tavg*Zavg*c3
-                 + D*L*Ps**2*Q**2*SG*Tavg*Zavg
-                 + L*Ps**2*Q**2*SG*Tavg*Zavg*c4)/(D**6*E**2*Ts**2*c5**2))**0.5
+        return sqrt((D**6*E**2*P2**2*Ts**2*c5**2
+                         + D**2*L*Ps**2*Q**2*SG*Tavg*Zavg*c3
+                         + D*L*Ps**2*Q**2*SG*Tavg*Zavg
+                         + L*Ps**2*Q**2*SG*Tavg*Zavg*c4)/(D**6*E**2*Ts**2*c5**2))
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return ((D**6*E**2*P1**2*Ts**2*c5**2
-                 - D**2*L*Ps**2*Q**2*SG*Tavg*Zavg*c3
-                 - D*L*Ps**2*Q**2*SG*Tavg*Zavg
-                 - L*Ps**2*Q**2*SG*Tavg*Zavg*c4)/(D**6*E**2*Ts**2*c5**2))**0.5
+        return sqrt((D**6*E**2*P1**2*Ts**2*c5**2
+                         - D**2*L*Ps**2*Q**2*SG*Tavg*Zavg*c3
+                         - D*L*Ps**2*Q**2*SG*Tavg*Zavg
+                         - L*Ps**2*Q**2*SG*Tavg*Zavg*c4)/(D**6*E**2*Ts**2*c5**2))
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return (D**6*E**2*Ts**2*c5**2*(P1**2 - P2**2)
                 /(Ps**2*Q**2*SG*Tavg*Zavg*(D**2*c3 + D + c4)))
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
+def _to_solve_Spitzglass_low(D, Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E):
+    return Q - Spitzglass_low(SG=SG, Tavg=Tavg, L=L, D=D, P1=P1, P2=P2, Ts=Ts, Ps=Ps, Zavg=Zavg, E=E)
 
 def Spitzglass_low(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-                Ps=101325., Zavg=1, E=1.):
+                Ps=101325., Zavg=1.0, E=1.):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Spitzglass (low pressure drop) formula. Can calculate
     any of the following, given all other inputs:
@@ -1406,7 +1407,7 @@ def Spitzglass_low(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1468,10 +1469,9 @@ def Spitzglass_low(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     c4 = 0.09144
     c5 = 125.1060
     if Q is None and L is not None and D is not None and P1 is not None and P2 is not None:
-        return c5*Ts/Ps*D**2.5*E*(((P1-P2)*2*(Ps+1210.))/(L*SG*Tavg*Zavg*(1 + c4/D + c3*D)))**0.5
+        return c5*Ts/Ps*D**2.5*E*sqrt(((P1-P2)*2*(Ps+1210.))/(L*SG*Tavg*Zavg*(1 + c4/D + c3*D)))
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
-        to_solve = lambda D : Q - Spitzglass_low(SG=SG, Tavg=Tavg, L=L, D=D, P1=P1, P2=P2, Ts=Ts, Ps=Ps, Zavg=Zavg, E=E)
-        return secant(to_solve, 0.5)
+        return secant(_to_solve_Spitzglass_low, 0.5, args=(Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E))
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
         return 0.5*(2.0*D**6*E**2*P2*Ts**2*c5**2*(Ps + 1210.0) + D**2*L*Ps**2*Q**2*SG*Tavg*Zavg*c3 + D*L*Ps**2*Q**2*SG*Tavg*Zavg + L*Ps**2*Q**2*SG*Tavg*Zavg*c4)/(D**6*E**2*Ts**2*c5**2*(Ps + 1210.0))
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
@@ -1479,13 +1479,15 @@ def Spitzglass_low(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return 2.0*D**6*E**2*Ts**2*c5**2*(P1*Ps + 1210.0*P1 - P2*Ps - 1210.0*P2)/(Ps**2*Q**2*SG*Tavg*Zavg*(D**2*c3 + D + c4))
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
+def _to_solve_Oliphant(D, Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E):
+    return Q - Oliphant(SG=SG, Tavg=Tavg, L=L, D=D, P1=P1, P2=P2, Ts=Ts, Ps=Ps, Zavg=Zavg, E=E)
 
 def Oliphant(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-             Ps=101325., Zavg=1, E=0.92):
+             Ps=101325., Zavg=1.0, E=0.92):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Oliphant formula. Can calculate any of the following,
     given all other inputs:
@@ -1519,7 +1521,7 @@ def Oliphant(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1563,24 +1565,23 @@ def Oliphant(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     c1 = 84.587176139918568651410168968141078948974609375000
     c2 = 0.2091519350460528670065940559652517549694 # 1/(30.*0.0254**0.5)
     if Q is None and L is not None and D is not None and P1 is not None and P2 is not None:
-        return c1*(D**2.5 + c2*D**3)*Ts/Ps*((P1**2-P2**2)/(L*SG*Tavg))**0.5
+        return c1*(D**2.5 + c2*D**3)*Ts/Ps*sqrt((P1**2-P2**2)/(L*SG*Tavg))
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
-        to_solve = lambda D : Q - Oliphant(SG=SG, Tavg=Tavg, L=L, D=D, P1=P1, P2=P2, Ts=Ts, Ps=Ps, Zavg=Zavg, E=E)
-        return secant(to_solve, 0.5)
+        return secant(_to_solve_Oliphant, 0.5, args=(Q, SG, Tavg, L, P1, P2, Ts, Ps, Zavg, E))
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*Ps**2*Q**2*SG*Tavg/(Ts**2*c1**2*(D**3*c2 + D**2.5)**2) + P2**2)**0.5
+        return sqrt(L*Ps**2*Q**2*SG*Tavg/(Ts**2*c1**2*(D**3*c2 + D**2.5)**2) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*Ps**2*Q**2*SG*Tavg/(Ts**2*c1**2*(D**3*c2 + D**2.5)**2) + P1**2)**0.5
+        return sqrt(-L*Ps**2*Q**2*SG*Tavg/(Ts**2*c1**2*(D**3*c2 + D**2.5)**2) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return Ts**2*c1**2*(P1**2 - P2**2)*(D**3*c2 + D**2.5)**2/(Ps**2*Q**2*SG*Tavg)
     else:
-        raise Exception('This function solves for either flow, upstream \
+        raise ValueError('This function solves for either flow, upstream \
 pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
 
 def Fritzsche(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7, 
-              Ps=101325., Zavg=1, E=1):
+              Ps=101325., Zavg=1.0, E=1.0):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Fritzsche formula. Can calculate any of the following,
     given all other inputs:
@@ -1615,7 +1616,7 @@ def Fritzsche(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1664,17 +1665,17 @@ def Fritzsche(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Ps*Q*(SG**(-c2)*(P1**2 - P2**2)/(L*Tavg*Zavg))**(-c3)/(E*Ts*c5))**(1./c4)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*SG**c2*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P2**2)**0.5
+        return sqrt(L*SG**c2*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*SG**c2*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P1**2)**0.5
+        return sqrt(-L*SG**c2*Tavg*Zavg*(D**(-c4)*Ps*Q/(E*Ts*c5))**(1./c3) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return SG**(-c2)*(D**(-c4)*Ps*Q/(E*Ts*c5))**(-1./c3)*(P1**2 - P2**2)/(Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
+        raise ValueError('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
 
 
 def Muller(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-           Ps=101325., Zavg=1, E=1):
+           Ps=101325., Zavg=1.0, E=1.0):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Muller formula. Can calculate any of the following,
     given all other inputs:
@@ -1712,7 +1713,7 @@ def Muller(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1774,17 +1775,17 @@ def Muller(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Ps*Q*SG**c4*mu**c1*((P1**2 - P2**2)/(L*Tavg*Zavg))**(-c2)/(E*Ts*c5))**(1./c3)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P2**2)**0.5
+        return sqrt(L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P1**2)**0.5
+        return sqrt(-L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return (D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(-1/c2)*(P1**2 - P2**2)/(Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
+        raise ValueError('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
 
 
 def IGT(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
-        Ps=101325., Zavg=1, E=1):
+        Ps=101325., Zavg=1.0, E=1.0):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the IGT formula. Can calculate any of the following,
     given all other inputs:
@@ -1822,7 +1823,7 @@ def IGT(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     P2 : float, optional
         Outlet pressure from pipe, [Pa]
     Q : float, optional
-        Flow rate of gas through pipe, [m^3/s]
+        Flow rate of gas through pipe at `Ts` and `Ps`, [m^3/s]
     Ts : float, optional
         Reference temperature for the specific gravity of the gas, [K]
     Ps : float, optional
@@ -1881,10 +1882,10 @@ def IGT(SG, Tavg, mu, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
     elif D is None and L is not None and Q is not None and P1 is not None and P2 is not None:
         return (Ps*Q*SG**c4*mu**c1*((P1**2 - P2**2)/(L*Tavg*Zavg))**(-c2)/(E*Ts*c5))**(1./c3)
     elif P1 is None and L is not None and Q is not None and D is not None and P2 is not None:
-        return (L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P2**2)**0.5
+        return sqrt(L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P2**2)
     elif P2 is None and L is not None and Q is not None and D is not None and P1 is not None:
-        return (-L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P1**2)**0.5
+        return sqrt(-L*Tavg*Zavg*(D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(1/c2) + P1**2)
     elif L is None and P2 is not None and Q is not None and D is not None and P1 is not None:
         return (D**(-c3)*Ps*Q*SG**c4*mu**c1/(E*Ts*c5))**(-1/c2)*(P1**2 - P2**2)/(Tavg*Zavg)
     else:
-        raise Exception('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
+        raise ValueError('This function solves for either flow, upstream pressure, downstream pressure, diameter, or length; all other inputs must be provided.')
