@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,10 +18,11 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import exp, log, log10, tanh
+from math import sqrt, exp, log, log10, tanh
 from fluids.constants import g
 from fluids.numerics import secant
 from fluids.core import Reynolds
@@ -33,8 +34,6 @@ __all__ = ['drag_sphere', 'drag_sphere_methods', 'v_terminal', 'integrate_drag_s
 'Swamee_Ojha', 'Yen', 'Haider_Levenspiel', 'Cheng', 'Terfous',
 'Mikhailov_Freire', 'Clift', 'Ceylan', 'Almedeij', 'Morrison', 'Song_Xu']
 
-__numba_additional_funcs__ = ['_v_terminal_err']
-
 def Stokes(Re):
     r'''Calculates drag coefficient of a smooth sphere using Stoke's law.
 
@@ -208,7 +207,7 @@ def Rouse(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re + 3/Re**0.5 + 0.34
+    return 24./Re + 3/sqrt(Re) + 0.34
 
 
 def Engelund_Hansen(Re):
@@ -395,7 +394,7 @@ def Graf(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re + 7.3/(1 + Re**0.5) + 0.25
+    return 24./Re + 7.3/(1 + sqrt(Re)) + 0.25
 
 
 def Flemmer_Banks(Re):
@@ -523,7 +522,7 @@ def Swamee_Ojha(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = 0.5*(16*((24./Re)**1.6 + (130./Re)**0.72)**2.5 + ((40000./Re)**2 + 1)**-0.25)**0.25
+    Cd = 0.5*sqrt(sqrt(16*((24./Re)**1.6 + (130./Re)**0.72)**2.5 + 1.0/sqrt(sqrt((40000./Re)**2 + 1))))
     return Cd
 
 
@@ -565,7 +564,7 @@ def Yen(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re*(1 + 0.15*Re**0.5 + 0.017*Re) - 0.208/(1 + 1E4*Re**-0.5)
+    return 24./Re*(1 + 0.15*sqrt(Re) + 0.017*Re) - 0.208/(1 + 1E4*1.0/sqrt(Re))
 
 
 def Haider_Levenspiel(Re):
@@ -847,8 +846,8 @@ def Ceylan(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = (1 - 0.5*exp(0.182) + 10.11*Re**(-2/3.)*exp(0.952*Re**-0.25)
-    - 0.03859*Re**(-4/3.)*exp(1.30*Re**-0.5) + 0.037E-4*Re*exp(-0.125E-4*Re)
+    Cd = (1 - 0.5*exp(0.182) + 10.11*Re**(-2/3.)*exp(0.952/sqrt(sqrt(Re)))
+    - 0.03859*Re**(-4/3.)*exp(1.30/sqrt(Re)) + 0.037E-4*Re*exp(-0.125E-4*Re)
     - 0.116E-10*Re**2*exp(-0.444E-5*Re))
     return Cd
 
@@ -1032,7 +1031,7 @@ def drag_sphere_methods(Re, check_ranges=True):
 
     Examples
     --------
-    >>> len(drag_sphere_methods(200)
+    >>> len(drag_sphere_methods(200))
     20
     >>> len(drag_sphere_methods(200000, check_ranges=False))
     21
@@ -1059,14 +1058,11 @@ def drag_sphere_methods(Re, check_ranges=True):
             methods.append(key)
     return methods
 
-def drag_sphere(Re, Method=None, AvailableMethods=False):
+def drag_sphere(Re, Method=None):
     r'''This function handles calculation of drag coefficient on spheres.
     Twenty methods are available, all requiring only the Reynolds number of the
     sphere. Most methods are valid from Re=0 to Re=200,000. A correlation will
-    be automatically selected if none is specified. The full list of correlations
-    valid for a given Reynolds number can be obtained with the `AvailableMethods`
-    flag.
-
+    be automatically selected if none is specified.
     If no correlation is selected, the following rules are used:
 
         * If Re < 0.01, use Stoke's solution.
@@ -1092,22 +1088,13 @@ def drag_sphere(Re, Method=None, AvailableMethods=False):
     -------
     Cd : float
         Drag coefficient [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Cd` with the given `Re`
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         drag_sphere_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `Cd` with the given `Re`; DEPRECATED
     '''
-    if AvailableMethods:
-        import warnings
-        warnings.warn('Please use drag_sphere_methods', DeprecationWarning, stacklevel=2)
-        return drag_sphere_methods(Re)
     if Method is None:
         if Re > 0.1:
             # Smooth transition point between the two models
@@ -1173,7 +1160,7 @@ def drag_sphere(Re, Method=None, AvailableMethods=False):
 
 def _v_terminal_err(V, Method, Re_almost, main):
     Cd = drag_sphere(Re_almost*V, Method=Method)
-    return V - (main/Cd)**0.5
+    return V - sqrt(main/Cd)
 
 def v_terminal(D, rhop, rho, mu, Method=None):
     r'''Calculates terminal velocity of a falling sphere using any drag
@@ -1400,7 +1387,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     --------
     >>> integrate_drag_sphere(D=0.001, rhop=2200., rho=1.2, mu=1.78E-5, t=0.5,
     ... V=30, distance=True) 
-    (9.686465044053476, 7.8294546436299175)
+    (9.686465044053, 7.8294546436299)
     
     References
     ----------
@@ -1428,7 +1415,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
             # It is only necessary to integrate to terminal velocity
             t_to_terminal = time_v_terminal_Stokes(D, rhop, rho, mu, V0=V, tol=1e-9)
             if t_to_terminal > t:
-                raise Exception('Should never happen')
+                raise ValueError('Should never happen')
             V_end, x_end = integrate_drag_sphere(D=D, rhop=rhop, rho=rho, mu=mu, t=t_to_terminal, V=V, Method='Stokes', distance=True)
             # terminal velocity has been reached - V does not change, but x does
             # No reason to believe this isn't working even though it isn't
@@ -1467,7 +1454,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
             t2 = 0.0
         else:
 #            t2 = c2*V*V*Stokes(Re_ish*V)
-            t2 = c2*V*V*drag_sphere(Re_ish*V, Method=Method)
+            t2 = c2*V*V*drag_sphere(float(Re_ish*V), Method=Method)
         return c1 + t2
 
     # Number of intervals for the solution to be solved for; the integrator
