@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,10 +18,11 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import exp, pi
+from math import exp, pi, sqrt
 
 __all__ = ['dP_packed_bed', 'dP_packed_bed_methods', 'Ergun', 'Kuo_Nydegger', 'Jones_Krier', 'Carman', 'Hicks',
            'Brauer', 'KTA', 'Erdim_Akgiray_Demir', 'Fahien_Schriver', 
@@ -32,7 +33,7 @@ __all__ = ['dP_packed_bed', 'dP_packed_bed_methods', 'Ergun', 'Kuo_Nydegger', 'J
 
 
 
-def Ergun(dp, voidage, vs, rho, mu, L=1):
+def Ergun(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_ and [3]_. Eighteenth most
     accurate correlation overall in the review of [2]_.
@@ -114,7 +115,7 @@ def Ergun(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1):
+def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_ and [3]. Thirty-eighth most
     accurate correlation overall in the review of [2]_.
@@ -179,7 +180,7 @@ def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Tallmadge(dp, voidage, vs, rho, mu, L=1):
+def Tallmadge(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_ and [3]. 
 
@@ -242,7 +243,7 @@ def Tallmadge(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Jones_Krier(dp, voidage, vs, rho, mu, L=1):
+def Jones_Krier(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, also shown in [2]_. Tenth most accurate
     correlation overall in the review of [2]_.
@@ -304,7 +305,7 @@ def Jones_Krier(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Carman(dp, voidage, vs, rho, mu, L=1):
+def Carman(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Fifth most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -367,7 +368,7 @@ def Carman(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Hicks(dp, voidage, vs, rho, mu, L=1):
+def Hicks(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Twenty-third most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -430,7 +431,7 @@ def Hicks(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Brauer(dp, voidage, vs, rho, mu, L=1):
+def Brauer(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Seventh most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -494,7 +495,7 @@ def Brauer(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def KTA(dp, voidage, vs, rho, mu, L=1):
+def KTA(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Third most accurate
     correlation overall in the review of [2]_.
@@ -557,7 +558,7 @@ def KTA(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1):
+def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, claiming to be the best model to date.
 
@@ -616,7 +617,7 @@ def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1):
     return fv*(mu*vs*L/dp**2)*(1-voidage)**2/voidage**3
 
 
-def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1):
+def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Second most accurate
     correlation overall in the review of [2]_.
@@ -691,7 +692,7 @@ def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Idelchik(dp, voidage, vs, rho, mu, L=1):
+def Idelchik(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres as in [2]_,
     originally in [1]_.
 
@@ -747,7 +748,7 @@ def Idelchik(dp, voidage, vs, rho, mu, L=1):
        590-600. doi:10.1016/j.powtec.2013.06.022.
     '''
     Re = rho*vs*dp/mu/(1-voidage)
-    Re = (0.45/voidage**0.5)*Re
+    Re = (0.45/sqrt(voidage))*Re
     right = 0.765/voidage**4.2*(30./Re + 3./Re**0.7 + 0.3)
     left = dp/L/rho/vs**2
     return right/left
@@ -900,12 +901,12 @@ def Montillet_Akkari_Comiti(dp, voidage, vs, rho, mu, L=1, Dt=None):
         Dterm = 2.2
     else:
         Dterm = (Dt/dp)**0.2
-    right = a*Dterm*(1000./Re + 60/Re**0.5 + 12)
+    right = a*Dterm*(1000./Re + 60/sqrt(Re) + 12)
     left = dp/L/rho/vs**2*voidage**3/(1-voidage)
     return right/left
 
 
-def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1):
+def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_. This is valid for highly-packed particles 
     at particle/tube diameter ratios between 2 and 3, where a ring packing 
@@ -1003,7 +1004,7 @@ def dP_packed_bed_methods(dp, voidage, vs, rho, mu, L=1.0, Dt=None, check_ranges
 
     Examples
     --------
-    >>> dP_packed_bed_methods(dp=8E-4, voidage=0.4, vs=1E-3, rho=1E3, mu=1E-3, L=1)[0]
+    >>> dP_packed_bed_methods(dp=8E-4, voidage=0.4, vs=1E-3, rho=1E3, mu=1E-3, L=1.0)[0]
     'Erdim, Akgiray & Demir'
     >>> dP_packed_bed_methods(dp=8E-4, voidage=0.4, vs=1E-3, rho=1E3, mu=1E-3, L=1, Dt=1e-2)[0]
     'Harrison, Brunner & Hecker'
@@ -1046,7 +1047,7 @@ def dP_packed_bed_methods(dp, voidage, vs, rho, mu, L=1.0, Dt=None, check_ranges
 
 
 def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
-                  Method=None, AvailableMethods=False):
+                  Method=None):
     r'''This function handles choosing which pressure drop in a packed bed
     correlation is used. Automatically select which correlation
     to use if none is provided. Returns None if insufficient information is
@@ -1091,24 +1092,14 @@ def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
     -------
     dP : float
         Pressure drop across the bed [Pa]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `dP` with the given inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         packed_beds_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `dP` with the given inputs and return them as a list.
-        DEPRECATED!
     '''
 
-    if AvailableMethods:
-        import warnings
-        warnings.warn('Please use dP_packed_bed_methods', DeprecationWarning, stacklevel=2)
-        return dP_packed_bed_methods(dp, voidage, vs, rho, mu, L, Dt)
     if Method is None:
         Method2 = 'Harrison, Brunner & Hecker' if Dt is not None else 'Erdim, Akgiray & Demir'
     else:
