@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -20,11 +20,11 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
-This module contains correlations and functions for calculating pressure drop 
+This module contains correlations and functions for calculating pressure drop
 from packings and demisters; separation efficiency of demisters; demister
 pressure drop; and demister geometry.
 
-For reporting bugs, adding feature requests, or submitting pull requests, 
+For reporting bugs, adding feature requests, or submitting pull requests,
 please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
 or contact the author at Caleb.Andrew.Bell@gmail.com.
 
@@ -55,12 +55,12 @@ Demister Geometry
 -----------------
 .. autofunction:: fluids.packed_tower.voidage_experimental
 .. autofunction:: fluids.packed_tower.specific_area_mesh
-'''
+"""
 
 from __future__ import division
-from math import log
+from math import log, sqrt
 from fluids.constants import g, pi
-from fluids.numerics import secant, newton_system
+from fluids.numerics import secant, newton_system, solve_2_direct, numpy as np
 
 __all__ = ['voidage_experimental', 'specific_area_mesh',
 'Stichlmair_dry', 'Stichlmair_wet', 'Stichlmair_flood', 'Robbins',
@@ -68,11 +68,9 @@ __all__ = ['voidage_experimental', 'specific_area_mesh',
 'dP_demister_dry_Setekleiv_Svendsen',
 'dP_demister_wet_ElDessouky', 'separation_demister_ElDessouky']
 
-__numba_additional_funcs__ = ['_Stichlmair_flood_f', '_Stichlmair_flood_f_and_jac',
-                              '_Stichlmair_wet_err']
 ### Demister
 
-def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1):
+def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1.0):
     r'''Calculates dry pressure drop across a demister, using the
     correlation in [1]_. This model is for dry demisters with no holdup only.
 
@@ -124,7 +122,7 @@ def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1):
     return right*rho*vs**2/voidage**2
 
 
-def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
+def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1.0):
     r'''Calculates dry pressure drop across a demister, using the
     correlation in [1]_. This model is for dry demisters with no holdup only.
     Developed with literature data included as well as their own experimental
@@ -163,7 +161,7 @@ def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
 
     Examples
     --------
-    >>> dP_demister_dry_Setekleiv_Svendsen_lit(S=250, voidage=.983, vs=1.2, rho=10, mu=3E-5, L=1)
+    >>> dP_demister_dry_Setekleiv_Svendsen_lit(S=250, voidage=.983, vs=1.2, rho=10, mu=3E-5, L=1.0)
     209.083848658307
 
     References
@@ -178,7 +176,7 @@ def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
     return right*rho*vs**2/voidage**2
 
 
-def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1):
+def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1.0):
     r'''Calculates wet pressure drop across a demister, using the
     correlation in [1]_. Uses only their own experimental data.
     
@@ -443,7 +441,7 @@ def Stichlmair_dry(Vg, rhog, mug, voidage, specific_area, C1, C2, C3, H=1.):
     Examples
     --------
     >>> Stichlmair_dry(Vg=0.4, rhog=5., mug=5E-5, voidage=0.68,
-    ... specific_area=260., C1=32., C2=7, C3=1)
+    ... specific_area=260., C1=32., C2=7.0, C3=1.0)
     236.80904286559885
 
     References
@@ -455,7 +453,7 @@ def Stichlmair_dry(Vg, rhog, mug, voidage, specific_area, C1, C2, C3, H=1.):
     '''
     dp = 6*(1-voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     return 3/4.*f0*(1-voidage)/voidage**4.65*rhog*H/dp*Vg**2
 
 
@@ -464,7 +462,7 @@ def _Stichlmair_wet_err(dP_irr, h0, c1, dP_dry, H, voidage, c):
     err = dP_dry/H*((1-voidage+hT)/(1.0 - voidage))**((2.0 + c)/3.)*(voidage/(voidage-hT))**4.65 -dP_irr/H
     return err
 
-def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3, H=1):
+def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3, H=1.0):
     r'''Calculates dry pressure drop across a packed column, using the
     Stichlmair [1]_ correlation. Uses three regressed constants for each
     type of packing, and voidage and specific area. This model is for irrigated
@@ -559,9 +557,9 @@ def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
     '''
     dp = 6.0*(1.0 - voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     dP_dry = 3/4.*f0*(1-voidage)/voidage**4.65*rhog*H/dp*Vg*Vg
-    c = (-C1/Re - C2/(2*Re**0.5))/f0
+    c = (-C1/Re - C2/(2*sqrt(Re)))/f0
     Frl = Vl**2*specific_area/(g*voidage**4.65)
     h0 = 0.555*Frl**(1/3.)
     
@@ -572,15 +570,14 @@ def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
 
 def _Stichlmair_flood_f(inputs, Vl, rhog, rhol, mug, voidage, specific_area,
                         C1, C2, C3, H):
-    '''Internal function which calculates the errors of the two Stichlmair
-    objective functions, and their jacobian.
-    '''
+    """Internal function which calculates the errors of the two Stichlmair
+    objective functions, and their jacobian."""
     Vg, dP_irr = float(inputs[0]), float(inputs[1])
     dp = 6.0*(1.0 - voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     dP_dry = 0.75*f0*(1.0 - voidage)/voidage**4.65*rhog*H/dp*Vg*Vg
-    c = (-C1/Re - 0.5*C2*Re**-0.5)/f0
+    c = (-C1/Re - 0.5*C2*1.0/sqrt(Re))/f0
     Frl = Vl*Vl*specific_area/(g*voidage**4.65)
     h0 = 0.555*Frl**(1/3.)
     hT = h0*(1.0 + 20.0*(dP_irr/H/rhol/g)**2)
@@ -590,15 +587,14 @@ def _Stichlmair_flood_f(inputs, Vl, rhog, rhol, mug, voidage, specific_area,
     - 186.0*h0/(voidage - h0*(1.0 + 20.0*term)))
     return err1, err2
 
-
 def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage, 
                                 specific_area, C1, C2, C3, H):
-    '''Internal function which calculates the errors of the two Stichlmair
+    """Internal function which calculates the errors of the two Stichlmair
     objective functions, and their jacobian.
-    
+
     Derived using SymPy on the main flooding function.
-    '''
-    Vg, dP_irr = float(inputs[0]), float(inputs[1])
+    """
+    Vg, dP_irr = inputs[0], inputs[1]
     x0 = 1.0/H
     x1 = Vg*Vg
     x2 = voidage**(-4.65)
@@ -622,12 +618,12 @@ def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage,
     x20 = C1*mug*specific_area*x16*x17*x19
     x21 = 2.44948974278318*C2
     x22 = Vg*rhog/(mug*specific_area)
-    x23 = x21*(-x18*x22)**-0.5
+    x23 = x21*1.0/sqrt(-x18*x22)
     x24 = 6.0*C3 - x20 + x23
     x25 = 1.0 - voidage 
     x26 = x14 + x25
     x27 = -x19*x26
-    x28 = 2.0*C1*mug*specific_area*x16*x17/x25 + x21*(x22*x25)**-0.5
+    x28 = 2.0*C1*mug*specific_area*x16*x17/x25 + x21*1.0/sqrt(x22*x25)
     x29 = 1.0/x24
     x30 = x28*x29
     x31 = x27**(-0.166666666666667*x30 + 0.666666666666667)
@@ -748,7 +744,7 @@ def Stichlmair_flood(Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
     guess[1] = 1000.0
     return newton_system(_Stichlmair_flood_f_and_jac, x0=guess, jac=True,
                          args=(Vl, rhog, rhol, mug, voidage, specific_area, C1, 
-                         C2, C3, H), ytol=1e-11)[0][0]
+                         C2, C3, H), ytol=1e-11, solve_func=solve_2_direct)[0][0]
 
 
 def Robbins(L, G, rhol, rhog, mul, H=1.0, Fpd=24.0):
@@ -815,9 +811,9 @@ def Robbins(L, G, rhol, rhog, mul, H=1.0, Fpd=24.0):
 
     C3 = 7.4E-8
     C4 = 2.7E-5
-    Fpd_root_term = (.05*Fpd)**0.5
+    Fpd_root_term = sqrt(.05*Fpd)
     Lf = L*(62.4/rhol)*Fpd_root_term*mul**0.1
-    Gf = G*(0.075/rhog)**0.5*Fpd_root_term
+    Gf = G*sqrt(0.075/rhog)*Fpd_root_term
     Gf2 = Gf*Gf
     C4LF_10_GF2_C3 = C3*Gf2*10.0**(C4*Lf)
     C4LF_10_GF2_C3_2 = C4LF_10_GF2_C3*C4LF_10_GF2_C3
