@@ -40,7 +40,7 @@ def log_uniform(low, high):
 
 def test_fittings():
     
-    K = entrance_beveled_orifice(Di=0.1, do=.07, l=0.003, angle=45)
+    K = entrance_beveled_orifice(Di=0.1, do=.07, l=0.003, angle=45.0)
     assert_close(K, 1.2987552913818574)
 
     ### Exits
@@ -53,16 +53,11 @@ def test_fittings():
     assert_close(K_spiral, 7.950918552775473)
 
     ### Contractions
-    K_sharp = contraction_sharp(Di1=1, Di2=0.4)
-    assert_close(K_sharp, 0.5301269161591805)
 
-
-    K_beveled = contraction_beveled(Di1=0.5, Di2=0.1, l=.7*.1, angle=120)
+    K_beveled = contraction_beveled(Di1=0.5, Di2=0.1, l=.7*.1, angle=120.0)
     assert_close(K_beveled, 0.40946469413070485)
 
     ### Expansions (diffusers)
-    K_sharp = diffuser_sharp(Di1=.5, Di2=1)
-    assert_close(K_sharp, 0.5625)
 
 
     K = diffuser_curved(Di1=.25**0.5, Di2=1., l=2.)
@@ -77,7 +72,7 @@ def test_fittings():
     # Misc
     K1 = Darby3K(NPS=2., Re=10000., name='Valve, Angle valve, 45°, full line size, β = 1')
     K2 = Darby3K(NPS=12., Re=10000., name='Valve, Angle valve, 45°, full line size, β = 1')
-    K3 = Darby3K(NPS=12., Re=10000., K1=950,  Ki=0.25,  Kd=4)
+    K3 = Darby3K(NPS=12., Re=10000., K1=950.,  Ki=0.25,  Kd=4.)
     Ks = [1.1572523963562353, 0.819510280626355, 0.819510280626355]
     assert_close1d([K1, K2, K3], Ks)
 
@@ -90,7 +85,7 @@ def test_fittings():
     assert_close(tot, 67.96442287975898)
 
     K1 = Hooper2K(Di=2., Re=10000., name='Valve, Globe, Standard')
-    K2 = Hooper2K(Di=2., Re=10000., K1=900, Kinfty=4)
+    K2 = Hooper2K(Di=2., Re=10000., K1=900., Kinfty=4.)
     assert_close1d([K1, K2], [6.15, 6.09])
     tot = sum([Hooper2K(Di=2., Re=10000., name=i) for i in Hooper.keys()])
     assert_close(tot, 46.18)
@@ -104,6 +99,7 @@ def test_fittings():
     assert_close(K2, 523.0201108796487)
         
 
+
 ### Entrances
 
 
@@ -170,10 +166,10 @@ def test_entrance_rounded():
         entrance_rounded(Di=0.1, rc=0.01, method='BADMETHOD')
 
 def test_entrance_beveled():
-    K = entrance_beveled(Di=0.1, l=0.003, angle=45)
+    K = entrance_beveled(Di=0.1, l=0.003, angle=45.0)
     assert_close(K, 0.45086864221916984)
 
-    K = entrance_beveled(Di=0.1, l=0.003, angle=45, method='Idelchik')
+    K = entrance_beveled(Di=0.1, l=0.003, angle=45.0, method='Idelchik')
     assert_close(K, 0.3995000000000001)
 
 
@@ -191,8 +187,8 @@ def test_entrance_sharp():
 
 def test_entrance_angled():
     K_30_Idelchik = 0.9798076211353316
-    assert_close(entrance_angled(30), K_30_Idelchik)
-    assert_close(entrance_angled(30, method='Idelchik'), K_30_Idelchik)
+    assert_close(entrance_angled(30.0), K_30_Idelchik)
+    assert_close(entrance_angled(30.0, method='Idelchik'), K_30_Idelchik)
 
     with pytest.raises(Exception):
         entrance_angled(30, method='BADMETHOD')
@@ -202,12 +198,19 @@ def test_entrance_angled():
 
 
 def test_bend_rounded_Crane():
-    K = bend_rounded_Crane(Di=.4020, rc=.4*5, angle=30)
+    K = bend_rounded_Crane(Di=.4020, rc=.4*5, angle=30.0)
     assert_close(K, 0.09321910015613409)
     
     K_max = bend_rounded_Crane(Di=.400, rc=.4*25, angle=30)
-    K_limit = bend_rounded_Crane(Di=.400, rc=.4*20, angle=30)
+    K_limit = bend_rounded_Crane(Di=.400, rc=.4*20, angle=30.0)
     assert_close(K_max, K_limit)
+    
+    # Test default
+    assert_close(bend_rounded_Crane(Di=.4020, rc=.4020*5, angle=30, bend_diameters=5.0),
+                 bend_rounded_Crane(Di=.4020, rc=.4020*5, angle=30.0))
+                 
+    with pytest.raises(Exception):
+        bend_rounded_Crane(Di=.4020, rc=.4*5, bend_diameters=8, angle=30)
 
 
 def test_bend_rounded_Miller():
@@ -225,7 +228,7 @@ def test_bend_rounded_Miller():
 
 def test_bend_rounded():
     ### Bends
-    K_5_rc = [bend_rounded(Di=4.020, rc=4.0*5, angle=i, fd=0.0163) for i in [15, 30, 45, 60, 75, 90]]
+    K_5_rc = [bend_rounded(Di=4.020, rc=4.0*5, angle=i, fd=0.0163) for i in [15.0, 30.0, 45, 60, 75, 90]]
     K_5_rc_values = [0.07038212630028828, 0.10680196344492195, 0.13858204974134541, 0.16977191374717754, 0.20114941557508642, 0.23248382866658507]
     assert_close1d(K_5_rc, K_5_rc_values)
 
@@ -233,32 +236,51 @@ def test_bend_rounded():
     K_10_rc_values =  [0.061075866683922314, 0.10162621862720357, 0.14158887563243763, 0.18225270014527103, 0.22309967045081655, 0.26343782210280947]
     assert_close1d(K_10_rc, K_10_rc_values)
 
-    K = bend_rounded(Di=4.020, bend_diameters=5, angle=30, fd=0.0163)
+    K = bend_rounded(Di=4.020, bend_diameters=5.0, angle=30.0, fd=0.0163)
     assert_close(K, 0.106920213333191)
     
-    K = bend_rounded(Di=4.020, bend_diameters=5, angle=30, Re=1E5)
+    K = bend_rounded(Di=4.020, bend_diameters=5.0, angle=30, Re=1E5)
     assert_close(K, 0.11532121658742862)
     
-    K = bend_rounded(Di=4.020, bend_diameters=5, angle=30, Re=1E5, method='Miller')
+    K = bend_rounded(Di=4.020, bend_diameters=5.0, angle=30, Re=1E5, method='Miller')
     assert_close(K, 0.10276501180879682)
     
-    K = bend_rounded(Di=.5, bend_diameters=5, angle=30, Re=1E5, method='Crane')
+    K = bend_rounded(Di=.5, bend_diameters=5.0, angle=30, Re=1E5, method='Crane')
     assert_close(K, 0.08959057097762159)
     
-    K = bend_rounded(Di=.5, bend_diameters=5, angle=30, Re=1E5, method='Ito')
+    K = bend_rounded(Di=.5, bend_diameters=5.0, angle=30, Re=1E5, method='Ito')
     assert_close(K, 0.10457946464978755)
     
-    K = bend_rounded(Di=.5, bend_diameters=5, angle=30, Re=1E5, method='Swamee')
+    K = bend_rounded(Di=.5, bend_diameters=5.0, angle=30, Re=1E5, method='Swamee')
     assert_close(K, 0.055429466248839564)
+    
+    assert type(bend_rounded(Di=4.020, rc=4.0*5, angle=30, Re=1E5, method='Miller')) == float
+    
+    # Crane standard fittings
+    Di = 4
+    v0 = bend_rounded(Di=4, angle=45, method='Crane standard')/ft_Crane(Di)
+    assert_close(v0, 16.0)
+    v0 = bend_rounded(Di=4, angle=90, method='Crane standard')/ft_Crane(Di)
+    assert_close(v0, 30.0)
+    v0 = bend_rounded(Di=4, angle=180, method='Crane standard')/ft_Crane(Di)
+    assert_close(v0, 50.0)
+    
+    # extrapolation - check behavior is sane
+    v0 = bend_rounded(Di=4, angle=360, method='Crane standard')/ft_Crane(Di)
+    assert_close(v0, 90.0)
+    
+    v0 = bend_rounded(Di=4, angle=0, method='Crane standard')/ft_Crane(Di)
+    assert_close(v0, 2.0)
+    
 
 
 
 def test_bend_miter():
-    K_miters =  [bend_miter(i) for i in [150, 120, 90, 75, 60, 45, 30, 15]]
+    K_miters =  [bend_miter(i) for i in [150.0, 120, 90, 75, 60, 45, 30, 15]]
     K_miter_values = [2.7128147734758103, 2.0264994448555864, 1.2020815280171306, 0.8332188430731828, 0.5299999999999998, 0.30419633092708653, 0.15308822558050816, 0.06051389308126326]
     assert_close1d(K_miters, K_miter_values)
     
-    K = bend_miter(Di=.6, angle=45, Re=1e6, roughness=1e-5, L_unimpeded=20, method='Miller')
+    K = bend_miter(Di=.6, angle=45.0, Re=1e6, roughness=1e-5, L_unimpeded=20.0, method='Miller')
     assert_close(K, 0.2944060416245167)
     
     K = bend_miter(Di=.05, angle=45, Re=1e6, roughness=1e-5, method='Crane')
@@ -273,16 +295,18 @@ def test_bend_miter():
 
 
 def test_bend_miter_Miller():
-    K = bend_miter_Miller(Di=.6, angle=45, Re=1e6, roughness=1e-5, L_unimpeded=20)
+    K = bend_miter_Miller(Di=.6, angle=45, Re=1e6, roughness=1e-5, L_unimpeded=20.0)
     assert_close(K, 0.2944060416245167)
     K_default_L_unimpeded = bend_miter_Miller(Di=.6, angle=45, Re=1e6, roughness=1e-5)
     assert_close(K, K_default_L_unimpeded)
     
     
-    K_high_angle = bend_miter_Miller(Di=.6, angle=120, Re=1e6, roughness=1e-5, L_unimpeded=20)
-    K_higher_angle = bend_miter_Miller(Di=.6, angle=150, Re=1e6, roughness=1e-5, L_unimpeded=20)
+    K_high_angle = bend_miter_Miller(Di=.6, angle=120.0, Re=1e6, roughness=1e-5, L_unimpeded=20.0)
+    K_higher_angle = bend_miter_Miller(Di=.6, angle=150.0, Re=1e6, roughness=1e-5, L_unimpeded=20.0)
     assert_close(K_high_angle, K_higher_angle)
     
+    assert type(bend_rounded_Miller(Di=.6, bend_diameters=2, angle=90,  Re=2e6,  roughness=2E-5, L_unimpeded=30*.6)) is float
+    
     
 @pytest.mark.slow
 @pytest.mark.fuzz
@@ -327,9 +351,30 @@ def test_bend_miter_Miller_fuzz():
 ### Diffusers
 
 
+def test_diffuser_sharp():
+    K_sharp = diffuser_sharp(Di1=.5, Di2=1.0)
+    assert_close(K_sharp, 0.5625, rtol=1e-12)
+    
+    K = diffuser_sharp(Di1=.5, Di2=1.0, Re=1e5, method='Hooper')
+    assert_close(K, 0.5705953978879232, rtol=1e-12)
+    
+    K = diffuser_sharp(Di1=.5, Di2=1.0, Re=1e3, method='Hooper')
+    assert_close(K, 1.875, rtol=1e-12)
+    
+    K = diffuser_sharp(Di1=.5, Di2=1.0, Re=1e5, fd=1e-7, method='Hooper')
+    assert_close(K, 0.562500045)
+    
+    with pytest.raises(Exception):
+        diffuser_sharp(Di1=.5, Di2=1.0, method='Hooper')
+    with pytest.raises(Exception):
+        diffuser_sharp(Di1=.5, Di2=1.0, method='BADMETHOD')
+
 def test_diffuser_conical():
+    
+    assert_close(diffuser_conical(Di1=1/3., Di2=1.0, angle=50.0, Re=1e7), 0.8017372988217512)
+    
     K1 = diffuser_conical(Di1=.1**0.5, Di2=1, angle=10., fd=0.020)
-    K2 = diffuser_conical(Di1=1/3., Di2=1, angle=50, fd=0.03) # 2
+    K2 = diffuser_conical(Di1=1/3., Di2=1, angle=50.0, fd=0.03) # 2
     K3 = diffuser_conical(Di1=2/3., Di2=1, angle=40, fd=0.03) # 3
     K4 = diffuser_conical(Di1=1/3., Di2=1, angle=120, fd=0.0185) # #4
     K5 = diffuser_conical(Di1=2/3., Di2=1, angle=120, fd=0.0185) # Last
@@ -341,7 +386,7 @@ def test_diffuser_conical():
     with pytest.raises(Exception):
         diffuser_conical(Di1=.1, Di2=0.1, fd=0.020)
 
-    K1 = diffuser_conical_staged(Di1=1., Di2=10., DEs=[2,3,4,5,6,7,8,9], ls=[1,1,1,1,1,1,1,1,1], fd=0.01)
+    K1 = diffuser_conical_staged(Di1=1., Di2=10., DEs=[2.0,3,4,5,6,7,8,9], ls=[1.0,1.0,1,1,1,1,1,1,1], fd=0.01)
     K2 = diffuser_conical(Di1=1., Di2=10.,l=9, fd=0.01)
     Ks = [1.7681854713484308, 0.973137914861591]
     assert_close1d([K1, K2], Ks)
@@ -351,11 +396,57 @@ def test_diffuser_conical():
     Ks_Idelchik_expect = [0.8617385829640242, 0.9283647028367953, 0.7082429168951839, 0.291016580744589, 0.18504484868875992, 0.147705693811332, 0.12911637682462676, 0.17]
     assert_close1d(Ks_Idelchik, Ks_Idelchik_expect, rtol=1e-2)
 
+    K = diffuser_conical(Di1=1/3., Di2=1.0, angle=50.0, Re=1E6, method='Hooper')
+    assert_close(K, 0.79748427282836)
 
-
+    K = diffuser_conical(Di1=1/3., Di2=1.0, angle=15.0, Re=1E6, method='Hooper')
+    assert_close(K, 0.2706407222679227)
+    
+    K = diffuser_conical(Di1=1/3., Di2=1.0, angle=15.0, Re=1E6, method='Hooper', fd=0.0)
+    assert_close(K, 0.26814269611625413)
+    
+    K = diffuser_conical(Di1=1/3., Di2=1.0, angle=15.0, Re=100, method='Hooper')
+    assert_close(K, 1.9753086419753085)
+    
+    with pytest.raises(Exception):
+        diffuser_conical(Di1=1/3., Di2=1.0, angle=15.0, method='Hooper')
+        
+    with pytest.raises(Exception):
+        diffuser_conical(Di1=1/3., Di2=1.0, angle=15.0, method='BADMETHOD')
 
 ### Contractions
 
+
+def test_contraction_sharp():
+    K_sharp = contraction_sharp(Di1=1.0, Di2=0.4)
+    assert_close(K_sharp, 0.5301269161591805)
+    
+    K = contraction_sharp(Di1=1.0, Di2=0.4, Re=1e5, method='Hooper')
+    assert_close(K, 0.5112534765075794)
+    
+    K = contraction_sharp(Di1=1, Di2=0.4, Re=1e3, method='Hooper')
+    assert_close(K, 1.3251840000000001)
+    
+    K = contraction_sharp(Di1=1, Di2=0.4, Re=1e7, fd=1e-5, method='Hooper')
+    assert_close(K, 0.5040040320000001)
+    
+    with pytest.raises(Exception):
+        contraction_sharp(Di1=1, Di2=0.4, method='Hooper')
+
+    with pytest.raises(Exception):
+            K = contraction_sharp(Di1=1, Di2=0.4, Re=1e5, method='BADMETHOD')
+            
+    K = contraction_sharp(3.0, 2.0, method='Crane')
+    assert_close(K, 0.2777777777777778)
+    
+    # From Crane 7-19 Water sample problem
+    # Convert back to the larger 3 inch diameter
+    K = change_K_basis(contraction_conical_Crane(3*inch, 2*inch, l=1e-10), 2.*inch, 3.*inch,)
+    assert_close(K, 1.4062499999999991)
+
+    K = change_K_basis(contraction_sharp(3*inch, 2*inch, method='Crane'), 2.*inch, 3.*inch,)
+    assert_close(K, 1.4062499999999991)
+
 def test_contraction_conical_Crane():
     K2 = contraction_conical_Crane(Di1=0.0779, Di2=0.0525, l=0)
     assert_close(K2, 0.2729017979998056)
@@ -363,24 +454,25 @@ def test_contraction_conical_Crane():
 
 
 def test_contraction_round():
-    K_round = contraction_round(Di1=1, Di2=0.4, rc=0.04)
+    K_round = contraction_round(Di1=1.0, Di2=0.4, rc=0.04)
     assert_close(K_round, 0.1783332490866574)
 
-    K = contraction_round(Di1=1, Di2=0.4, rc=0.04, method='Miller')
+    K = contraction_round(Di1=1.0, Di2=0.4, rc=0.04, method='Miller')
     assert_close(K, 0.085659530512986387)
 
-    K = contraction_round(Di1=1, Di2=0.4, rc=0.04, method='Idelchik')
+    K = contraction_round(Di1=1.0, Di2=0.4, rc=0.04, method='Idelchik')
     assert_close(K, 0.1008)
     
     with pytest.raises(Exception):
-        contraction_round(Di1=1, Di2=0.4, rc=0.04, method='BADMETHOD')
-
+        contraction_round(Di1=1.0, Di2=0.4, rc=0.04, method='BADMETHOD')
+        
 def test_contraction_round_Miller():
     K = contraction_round_Miller(Di1=1, Di2=0.4, rc=0.04)
     assert_close(K, 0.085659530512986387)
 
 
 def test_contraction_conical():
+    
     K_conical1 = contraction_conical(Di1=0.1, Di2=0.04, l=0.04, fd=0.0185)
     K_conical2 = contraction_conical(Di1=0.1, Di2=0.04, angle=73.74, fd=0.0185)
     assert_close1d([K_conical1, K_conical2], [0.15779041548350314, 0.15779101784158286])
@@ -425,6 +517,53 @@ def test_contraction_conical():
     with pytest.raises(Exception):
         contraction_conical(Di1=0.1, Di2=.04, l=.004, Re=1E6, method='BADMETHOD')
 
+    K = contraction_conical(Di1=0.1, Di2=0.04, l=0.04, Re=1E6, method='Hooper') # Turb, high angle
+    assert_close(K, 0.39403366995770217, rtol=1e-12)
+    
+    K = contraction_conical(Di1=0.1, Di2=0.04, l=.5, Re=1E6, method='Hooper') # low angle
+    assert_close(K, 0.04874708101353686, rtol=1e-12)
+    
+    K = contraction_conical(Di1=0.1, Di2=0.04, l=.5, Re=10, method='Hooper') # laminar
+    assert_close(K, 1.606041003307766)
+    
+    K = contraction_conical(Di1=0.1, Di2=0.04, l=.5, Re=1E6, fd=1e-6, method='Hooper')
+    assert_close(K, 0.04829718188073081)
+    
+    with pytest.raises(Exception):
+        # Need re to determine regime
+        contraction_conical(Di1=0.1, Di2=0.04, l=.5, fd=1e-6, method='Hooper')
+    with pytest.raises(Exception):
+        contraction_conical(Di1=0.1, Di2=0.04, l=.5, method='Rennels')
+        
+    # l_ratio > 0.6 case
+    K = contraction_conical(Di1=0.1, Di2=0.04, l=10, fd=1e-6, method='Blevins')
+    assert_close(K, 0.2025)
+    
+    # Case A_ratio > 10
+    K = contraction_conical(Di1=0.1, Di2=0.01, l=10, fd=1e-6, method='Blevins')
+    assert_close(K, 0.27)
+    
+    # Case with A_ratio < 1.2
+    K = contraction_conical(Di1=0.1, Di2=0.099999, l=100, fd=1e-6, method='Blevins')
+    assert_close(K, 0.03)
+    
+    # case angle_rad > 20.0*deg2rad
+    K = contraction_conical(Di1=1, Di2=0.01, l=.5, fd=1e-6, method='Idelchik')
+    assert_close(K, 0.21089636998777261)
+    
+    # case angle_rad < 2.0*deg2rad
+    K = contraction_conical(Di1=1, Di2=0.99, l=.5, fd=1e-6, method='Idelchik')
+    assert_close(K, 0.09947364590616913)
+    
+    # case angle_fric = angle_rad*rad2deg
+    K = contraction_conical(Di1=1, Di2=0.5, l=10, fd=1e-6, method='Idelchik')
+    assert_close(K, 0.431024986913148)
+    
+    # Default method
+    assert_close(contraction_conical(Di1=0.1, Di2=0.04, l=0.04, Re=1e6),
+                 contraction_conical(Di1=0.1, Di2=0.04, l=0.04, Re=1e6, method='Rennels'))
+
+
 ### Valves
 
 def test_valve_coefficients():
@@ -544,7 +683,7 @@ def test_K_lift_check_valve_Crane():
     
     
 def test_K_tilting_disk_check_valve_Crane():
-    K = K_tilting_disk_check_valve_Crane(.01, 5, fd=.016)
+    K = K_tilting_disk_check_valve_Crane(.01, 5.0, fd=.016)
     assert_close(K, 0.64)
     
     K = K_tilting_disk_check_valve_Crane(.25, 5, fd=.016)
@@ -607,7 +746,7 @@ def test_K_angle_stop_check_valve_Crane():
 
 
 def test_K_ball_valve_Crane():
-    K = K_ball_valve_Crane(.01, .02, 50, .025)
+    K = K_ball_valve_Crane(.01, .02, 50., .025)
     assert_close(K, 14.100545785228675)
     
     K = K_ball_valve_Crane(.01, .02, 40, .025)
@@ -666,7 +805,7 @@ def test_K_butterfly_valve_Crane():
         
         
 def test_K_plug_valve_Crane():
-    K = K_plug_valve_Crane(.01, .02, 50, .025)
+    K = K_plug_valve_Crane(.01, .02, 50.0, .025)
     assert_close(K, 20.100545785228675)
     
     K = K_plug_valve_Crane(.01, .02, 50, .025, style=1)
@@ -714,7 +853,7 @@ def test_K_run_converging_Crane():
     K = K_run_converging_Crane(0.1023, 0.1023, 0.018917, 0.00633)
     assert_close(K, 0.32575847854551254)
     
-    K =   K_run_converging_Crane(0.1023, 0.1023, 0.018917, 0.00633, angle=30)
+    K =   K_run_converging_Crane(0.1023, 0.1023, 0.018917, 0.00633, angle=30.0)
     assert_close(K, 0.32920396892611553)
     
     K = K_run_converging_Crane(0.1023, 0.1023, 0.018917, 0.00633, angle=60)
@@ -722,7 +861,7 @@ def test_K_run_converging_Crane():
     
     
 def test_K_branch_diverging_Crane():
-    K = K_branch_diverging_Crane(0.146, 0.146, 1515*liter/minute, 950*liter/minute, angle=45)
+    K = K_branch_diverging_Crane(0.146, 0.146, 1515*liter/minute, 950*liter/minute, angle=45.)
     assert_close(K, 0.4640, atol=0.0001)
     
     K = K_branch_diverging_Crane(0.146, 0.146, 0.02525, 0.01583, angle=90)
@@ -746,7 +885,7 @@ def test_K_branch_diverging_Crane():
     
     
 def test_K_run_diverging_Crane():
-    K = K_run_diverging_Crane(0.146, 0.146, 1515*liter/minute, 950*liter/minute, angle=45)
+    K = K_run_diverging_Crane(0.146, 0.146, 1515*liter/minute, 950*liter/minute, angle=45.)
     assert_close(K, -0.06809, atol=.00001)
     
     K =  K_run_diverging_Crane(0.146, 0.146, 0.01025, 0.01983, angle=45)
