@@ -27,7 +27,7 @@ from fluids import *
 import pytest
 from fluids.friction import _roughness, _Farshad_roughness
 
-def test_friction():
+def test_friction_basic():
     assert_close(Moody(1E5, 1E-4), 0.01809185666808665)
     assert_close(Alshul_1952(1E5, 1E-4), 0.018382997825686878)
     assert_close(Wood_1966(1E5, 1E-4), 0.021587570560090762)
@@ -59,17 +59,21 @@ def test_friction():
     assert_close(Fang_2011(1E5, 1E-4), 0.018481390682985432)
     assert_close(Clamond(1E5, 1E-4), 0.01851386607747165)
     assert_close(Clamond(1E5, 1E-4, fast=True), 0.01851486771096876)
-    
 
     assert_close(friction_laminar(128), 0.5)
 
-    assert_close(Blasius(10000), 0.03164)
+    assert_close(Blasius(10000.0), 0.03164)
 
+    fd = ft_Crane(.1)
+    assert_close(fd, 0.01628845962146481)
+    assert_close(ft_Crane(1e-5), 604.8402578042682)
+
+def test_friction():
     assert_close(sum(_roughness.values()), 0.01504508)
 
 
     assert_close(friction_factor(Re=1E5, eD=1E-4), 0.01851386607747165)
-    methods_1 = friction_factor(Re=1E5, eD=1E-4, AvailableMethods=True)
+    methods_1 = friction_factor_methods(Re=1E5, eD=1E-4)
     methods_1.sort()
 
     methods_2 = ['Clamond', 'Colebrook', 'Manadilli_1997', 'Haaland', 'Alshul_1952', 'Avci_Karagoz_2009', 'Rao_Kumar_2007', 'Zigrang_Sylvester_2', 'Eck_1973', 'Buzzelli_2008', 'Tsal_1989', 'Papaevangelo_2010', 'Barr_1981', 'Jain_1976', 'Moody', 'Brkic_2011_2', 'Brkic_2011_1', 'Swamee_Jain_1976', 'Wood_1966', 'Shacham_1980', 'Romeo_2002', 'Chen_1979', 'Fang_2011', 'Round_1980', 'Sonnad_Goudar_2006', 'Churchill_1973', 'Churchill_1977', 'Serghides_2', 'Serghides_1', 'Zigrang_Sylvester_1']
@@ -90,12 +94,8 @@ def test_friction():
 
     for m in friction_factor_methods(200, 0, False):   
         friction_factor(Re=1E5, eD=1e-6, Method=m)
-    
+        
     fd = ft_Crane(.1)
-    assert_close(fd, 0.01628845962146481)
-    
-    assert_close(ft_Crane(1e-5), 604.8402578042682)
-    
     Di = 0.1
     fd_act = Clamond(7.5E6*Di, eD=roughness_Farshad(ID='Carbon steel, bare', D=Di)/Di)
     assert_close(fd, fd_act, rtol=5e-6)
@@ -165,19 +165,19 @@ def test_Colebrook_hard_regimes():
 
 
 def test_one_phase_dP():
-    dP = one_phase_dP(10.0, 1000, 1E-5, .1, L=1)
+    dP = one_phase_dP(10.0, 1000., 1E-5, .1, L=1.000)
     assert_close(dP, 63.43447321097365)
     
 def test_one_phase_dP_gravitational():
-    dP = one_phase_dP_gravitational(angle=90, rho=2.6)
+    dP = one_phase_dP_gravitational(angle=90., rho=2.6)
     assert_close(dP, 25.49729)
 
-    dP = one_phase_dP_gravitational(angle=90, rho=2.6, L=2)
+    dP = one_phase_dP_gravitational(angle=90, rho=2.6, L=2.)
     assert_close(dP, 25.49729*2)
     
     
 def test_one_phase_dP_dz_acceleration():
-    dP = one_phase_dP_dz_acceleration(m=1, D=0.1, rho=827.1, dv_dP=-1.1E-5, dP_dL=5E5, dA_dL=0.0001)
+    dP = one_phase_dP_dz_acceleration(m=1., D=0.1, rho=827.1, dv_dP=-1.1E-5, dP_dL=5E5, dA_dL=0.0001)
     assert_close(dP, 89162.89116373913)
     
 
@@ -198,7 +198,7 @@ def test_one_phase_dP_dz_acceleration_example():
     D = 0.1
     def dP_dz(P, L, acc=False):
         s.flash(P=float(P), Hm=s.Hm)
-        dPf = one_phase_dP(m=s.m, rho=s.rhog, mu=s.rhog, D=D, roughness=0, L=1)
+        dPf = one_phase_dP(m=s.m, rho=s.rhog, mu=s.rhog, D=D, roughness=0, L=1.0)
     
         if acc:
             G = 4.0*s.m/(pi*D*D)
@@ -312,22 +312,22 @@ def test_Prandtl_von_Karman_Nikuradse_full():
 
 
 def test_helical_laminar_fd_White():
-    fd = helical_laminar_fd_White(250, .02, .1)
+    fd = helical_laminar_fd_White(250., .02, .1)
     assert_close(fd, 0.4063281817830202)
     assert_close(helical_laminar_fd_White(250, .02, 100), 0.256)
     
     
 def test_helical_laminar_fd_Mori_Nakayama():
-    fd = helical_laminar_fd_Mori_Nakayama(250, .02, .1)
+    fd = helical_laminar_fd_Mori_Nakayama(250., .02, .1)
     assert_close(fd, 0.4222458285779544)
     assert_close(4.4969472, helical_laminar_fd_Mori_Nakayama(20, .02, .1))
     
     
 def test_helical_laminar_fd_Schmidt():
-    fd = helical_laminar_fd_Schmidt(250, .02, .1)
+    fd = helical_laminar_fd_Schmidt(250., .02, .1)
     assert_close(fd, 0.47460725672835236)
     # Test convergence at low curvature 
-    assert_close(helical_laminar_fd_Schmidt(250, 1, 1E10), friction_laminar(250))
+    assert_close(helical_laminar_fd_Schmidt(250., 1, 1E10), friction_laminar(250))
     
     
 def test_helical_turbulent_fd_Srinivasan():
@@ -428,11 +428,6 @@ def test_friction_factor_curved():
     fd_rough_false = friction_factor_curved(20000, 0.01, .02, roughness=.0001, turbulent_method='Guo')
     assert_close(fd_rough_false, 0.1014240343662085)
     
-    methods = friction_factor_curved(20000, 0.01, .02, AvailableMethods=True)
-    assert sorted(methods) == sorted(['Guo','Ju','Schmidt turbulent','Prasad','Mandel Nigam','Mori Nakayama turbulent','Czop', 'Srinivasan turbulent'])
-    methods = friction_factor_curved(2000, 0.01, .02, AvailableMethods=True)
-    assert sorted(methods) == sorted(['White', 'Schmidt laminar', 'Mori Nakayama laminar'])
-
     methods = friction_factor_curved_methods(20000, 0.01, .02, check_ranges=True)
     assert sorted(methods) == sorted(['Guo','Ju','Schmidt turbulent','Prasad','Mandel Nigam','Mori Nakayama turbulent','Czop', 'Srinivasan turbulent'])
     methods = friction_factor_curved_methods(2000, 0.01, .02, check_ranges=True)
@@ -451,19 +446,19 @@ def test_friction_factor_curved():
         helical_Re_crit(Di=0.02, Dc=0.5, Method=m)
     
 def test_friction_plate():
-    fd = friction_plate_Martin_1999(Re=20000, plate_enlargement_factor=1.15)
+    fd = friction_plate_Martin_1999(Re=20000., plate_enlargement_factor=1.15)
     assert_close(fd, 2.284018089834134)
     
-    fd = friction_plate_Martin_1999(Re=1999, plate_enlargement_factor=1.15)
+    fd = friction_plate_Martin_1999(Re=1999., plate_enlargement_factor=1.15)
     assert_close(fd, 2.749383588479863)
     
-    fd = friction_plate_Martin_VDI(Re=20000, plate_enlargement_factor=1.15)
+    fd = friction_plate_Martin_VDI(Re=20000., plate_enlargement_factor=1.15)
     assert_close(fd, 2.702534119024076)
     
-    fd = friction_plate_Martin_VDI(Re=1999, plate_enlargement_factor=1.15)
+    fd = friction_plate_Martin_VDI(Re=1999., plate_enlargement_factor=1.15)
     assert_close(fd, 3.294294334690556)
     
-    fd = friction_plate_Muley_Manglik(Re=2000, chevron_angle=45, plate_enlargement_factor=1.2)
+    fd = friction_plate_Muley_Manglik(Re=2000., chevron_angle=45., plate_enlargement_factor=1.2)
     assert_close(fd, 1.0880870804075413)
 
 
